Third-party components
######################

-   The ``m.math`` plugin makes use of the **latex2svg** utility ---
    https://github.com/tuxu/latex2svg, licensed under
    `MIT license <https://github.com/tuxu/latex2svg/blob/master/LICENSE.md>`_

Contributors to m.css
#####################

Listing only people with code contributions, because otherwise there's too many
:) Big thanks to everyone involved!

-   Arvid Gerstmann (`@Leandros <https://github.com/Leandros>`_) ---
    Windows-related fixes, bugreports
-   Blair Conrad (`@blairconrad <https://github.com/blairconrad>`_) ---
    complete rewrite of the ANSI color lexer to be the *best ever*
-   `@Bridouz <https://github.com/Bridouz>`_ --- documentation improvements
-   Carlos Brito Pacheco (`@cbritopacheco <https://github.com/cbritopacheco>`_)
    --- compatibility with dvisvgm 2.12
-   `@crf8472 <https://github.com/crf8472>`_ --- Doxygen 1.9 compatibility
-   Cris Luengo (`@crisluengo <https://github.com/crisluengo>`_) ---
    complete handling of Doxygen entities and super/subscript elements, fixes
    for external docs in Markdown files, Doxygen 1.9 compatibility, style fixes
-   Dale Lukas Peterson (`@hazelnusse <https://github.com/hazelnusse>`_) ---
    documentation improvements
-   `@DarkContact <https://github.com/DarkContact>`_ --- Windows-related fixes
-   Erik Smistad (`@smistad <https://github.com/smistad>`_) --- search
    autocompletion fixes for mobile browsers
-   `@gotchafr <https://github.com/gotchafr>`_ --- Linux-related fixes
-   Guillaume Jacquemin (`@williamjcm <https://github.com/williamjcm>`_) ---
    Pelican theme fixes, semantic improvements to the ``m.htmlsanity`` plugin
-   `John Turner <https://github.com/jturner65>`_ --- docutils compatibility
    fixes
-   `@joshyrobot <https://github.com/joshyrobot>`_ --- CSS validity fixes
-   Lukas Pirl (`@lpirl <https://github.com/lpirl>`_) --- Pelican theme
    improvements, fixes for Pelican 4.5+ support
-   `@luzpaz <https://github.com/luzpaz>`_ --- Typo fixes
-   Marin (`@marinjurjevic <https://github.com/marinjurjevic>`_) --- Doxygen
    theme fixes
-   Mark Gillard (`@marzer <https://github.com/marzer>`_) --- Doxygen theme
    improvements, CSS fixes
-   Rémi Marche (`@Marr11317 <https://github.com/Marr11317>`_) --- Doxygen
    theme improvements
-   `@paulignari <https://github.com/paulignari>`_ --- i18n-related
    improvements
-   Ryohei Machida (`@machida-mn <https://github.com/machida-mn>`_) ---
    proof-of-concept implementation of ``#include`` information in the Doxygen
    theme
-   Sara Damiano (`@SRGDamia1 <https://github.com/SRGDamia1`_) --- Doxygen 1.9
    compatibility
-   Sergei Izmailov (`@sizmailov <https://github.com/sizmailov>`_) ---
    improvements to pybind11 support in the Python doc theme; theme, style and
    search fixes
-   `@shniubobo <https://github.com/shniubobo>`_ --- Fixes for Pelican 4.5
    compatibility
-   Varun Gandhi (`@typesanitizer <https://github.com/typesanitizer>`_) ---
    documentation updates
-   Yuri Edward (`@Yuri6037 <https://github.com/Yuri6037>`_) --- improvements
    to the Doxygen theme
